#
# spec file for package xmvn
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xmvn
Version:        4.2.0
Release:        6.2
Summary:        Local Extensions for Apache Maven
License:        Apache-2.0
Group:          Development/Tools/Building
URL:            https://fedora-java.github.io/xmvn/
BuildRequires:  %{name}-api = %{version}
BuildRequires:  %{name}-connector = %{version}
BuildRequires:  %{name}-core = %{version}
BuildRequires:  %{name}-subst
BuildRequires:  javapackages-tools
BuildRequires:  maven
BuildRequires:  maven-lib
Requires:       %{name}-minimal = %{version}-%{release}

%description
This package provides extensions for Apache Maven that can be used to
manage system artifact repository and use it to resolve Maven
artifacts in offline mode, as well as Maven plugins to help with
creating RPM packages containing Maven artifacts.

%package        minimal
Summary:        Dependency-reduced version of XMvn
Group:          Development/Tools/Building
Requires:       %{name}-api = %{version}
Requires:       %{name}-connector = %{version}
Requires:       %{name}-core = %{version}
%requires_eq    maven-lib

%description    minimal
This package provides minimal version of XMvn, incapable of using
remote repositories.

%prep

%build

%install
# Please, keep in sync with maven package, since the use
# of libalternatives in some distro versions makes it
# more tedious to detect automatically
maven_home=%{_datadir}/maven

install -d -m 755 %{buildroot}%{_datadir}/%{name}
cp -aL ${maven_home}/* %{buildroot}%{_datadir}/%{name}/

for i in api core connector; do
    ln -s $(build-classpath %{name}/%{name}-${i}) %{buildroot}%{_datadir}/%{name}/lib/ext/
done

# Irrelevant Maven launcher scripts
rm -f %{buildroot}%{_datadir}/%{name}/bin/*

for cmd in mvn mvnDebug; do
    cat <<EOF >%{buildroot}%{_datadir}/%{name}/bin/$cmd
#!/bin/sh -e
export _FEDORA_MAVEN_HOME="%{_datadir}/%{name}"
exec ${maven_home}/bin/$cmd "\${@}"
EOF
    chmod 755 %{buildroot}%{_datadir}/%{name}/bin/$cmd
done

# possibly recreate symlinks that can be automated with xmvn-subst
%{name}-subst -s -R %{buildroot} %{buildroot}%{_datadir}/%{name}/

# /usr/bin/xmvn
install -dm 0755 %{buildroot}%{_bindir}
ln -sf %{_datadir}/%{name}/bin/mvn %{buildroot}%{_bindir}/%{name}

# mvn-local symlink
ln -s %{name} %{buildroot}%{_bindir}/mvn-local

# make sure our conf is identical to maven so yum won't freak out
install -d -m 755 %{buildroot}%{_datadir}/%{name}/conf/
cp -P ${maven_home}/conf/settings.xml %{buildroot}%{_datadir}/%{name}/conf/
cp -P ${maven_home}/bin/m2.conf %{buildroot}%{_datadir}/%{name}/bin/

%pre minimal
if [ -L %{_datadir}/%{name}/conf/logging ]; then
    rm -f %{_datadir}/%{name}/conf/logging
fi

%files
%{_bindir}/mvn-local

%files minimal
%{_bindir}/%{name}
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/bin
%dir %{_datadir}/%{name}/lib
%{_datadir}/%{name}/lib/*.jar
%{_datadir}/%{name}/lib/ext
%{_datadir}/%{name}/lib/jansi-native
%{_datadir}/%{name}/bin/m2.conf
%{_datadir}/%{name}/bin/mvn
%{_datadir}/%{name}/bin/mvnDebug
%{_datadir}/%{name}/boot
%{_datadir}/%{name}/conf

%changelog
* Thu May  4 2023 Fridrich Strba <fstrba@suse.com>
- Add _multibuild to define 2nd spec file as additional flavor.
  Eliminates the need for source package links in OBS.
* Wed May  3 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 4.2.0
  * Changes:
    + Make XMvn Resolver log to XMvn Logger
    + Make XMvn Subst log to XMvn Logger
    + Depend on junit-jupiter-api instead of junit-jupiter
    + Suppress deprecation warnings in MavenExtensionTest
    + Remove XMvn Connector dependency on Plexus Utils
    + Remove XMvn MOJO dependency on Plexus Utils
    + Port XMvn MOJO from Xpp3Dom to StAX
    + Update Maven to version 3.9.1
    + Don't pass duplicate --patch-module to javadoc
    + Make Javadoc MOJO respect ignoreJPMS configuration flag
    + Propagate javadoc output througt Logger
    + Remove dependency on Plexus Classworlds
    + Remove unneeded managed dependency on maven-invoker
    + Use ServiceLocator to find Logger
    + Use parametrized logging feature
    + Use XMvn Logger instead of Plexus Logger
    + Get rid of Slf4jLoggerAdapter
    + Drop support for Gossip logger
    + Move XMvn Logger to API module
    + Ignore JPMS when all modules are automatic
    + Refactor Javadoc MOJO
    + Make Javadoc not fail when no sources are found
    + Add an integration test for javadoc generation with
    module-info.java but no sources
    + Add an integration test for javadoc generation with
    Automatic-Module-Name
    + Make Javadoc MOJO work in case one of JPMS modules has no
    sources
    + Prioritize certain XMvn components over Maven components
    + Port XMvn MOJO to JSR-330
    + Refactor XMvnMojoExecutionConfigurator
    + Make builddep MOJO compatible with Maven 4
    + Port to JSR-330
    + Get rid of ModelProcessor
    + Refactor XMvnModelValidator
    + Refactor XMvnToolchainManager
    + Convert lambda to method reference
    + Improve Javadoc MOJO JPMS support
    + Add a test case for JPMS javadoc generation with remote
    dependencies
    + Add a test case for JPMS multimodule javadoc generation
    + Exclude src/test/resources-filtered/** from RAT
    + Fix scope of xmvn-mojo dependency on plexus-utils
    + --module-path not allowed with release=8
    + Mimic maven-javadoc-plugin for -source and --release
    + testJavadocJPMS needs a modular java
    + Let modello generate source 8
    + Add a jdk9+ profile to assure that we are jdk8 compatible
    + Revert "Use new Collection methods added in Java 9"
    + Revert "Update compiler source/target to JDK 11"
    + Restore possibility to build with Java 8
    + Simple implementation of toolchains
    https://github.com/fedora-java/xmvn/issues/142
    + Port to Modello 2.0.0
* Tue May 10 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 4.0.0
  * Changes:
    +  Bump codecov/codecov-action from 2.0.1 to 2.0.2
    +  Bump codecov/codecov-action from 1 to 2.0.1
    +  Bump commons-compress from 1.20 to 1.21 in /xmvn-parent
    +  Change logic for JPMS detection by Javadoc MOJO
    +  Fix Javadoc generation for non-JPMS project with JDK 11
    +  Remove superflous JARs from assembly
    +  Create a backup file when injecting Manifest
    +  Attach site artifacts only in site lifecycle
    +  Rename xmvn-connector-aether to xmvn-connector
    +  Use try-with-resources to avoid resource leaks
    +  Remove unused AtomicFileCounter class
    +  Update Eclipse project settings
    +  Add separate build profile for code quality tools
    +  Remove prerequisites on Maven version
    +  Drop bisect tool
    +  Move release plugins to pluginManagement
    +  Move prerequisites on Maven version to xmvn-mojo
    +  Fix javadoc warning
    +  Bump junit from 4.12 to 4.13.1 in /xmvn-it/src/test/resources/testBisect
    +  Bump slf4jVersion from 1.8.0-beta4 to 2.0.0-alpha2 in /xmvn-parent
    +  Compile everything whith --release 11
    +  Fix assembly building with Maven Checkstyle Plugin 3.1.0+
    +  Update to latest Checkstyle
    +  Format code to conform to Checkstyle 8.44
    +  Untabify Maven build files
    +  Update Maven plugin versions
    +  Drop Ivy
    +  Drop Gradle
    +  Add support for compiler release setting
    +  Fix Javadoc generation for modular projects
    +  Add JPMS check to Javadoc MOJO
    +  Add missing license headers
    +  Disable I/O write test if the build is running as root
    +  Switch to SHA-256 in CacheManager
    +  Update dependency xmlunit.assertj to xmlunit.assertj3
    +  Fixes #56 - Honour source parameter in javadoc mojo
    +  Implement XMvn toolchain manager
    +  Fix requires generation for self-depending packages
    +  Remove redundant parentheses
    +  Remove redudnant use of this
    +  Relay on implicit access modifiers of interfaces
    +  Rely on implicit boxing
    +  Make use of diamond operator
    +  [test] Use use lambda expressions for creation of DeploymentResult
    +  Remove use of deprecated StringUtils methods
    +  [test] Port tests to JUnit 5
    +  Update to latest dependencies
    +  [test] Add missing assertions about XML output
    +  Use new Collection methods added in Java 9
    +  Remove uses of deprecated Class.newInstance() method
    +  Drop artifact resolution from JAVA_HOME
    +  Update to latest Maven plugin versions
    +  Update compiler source/target to JDK 11
    +  Update Eclipse project settings
    +  Make xmvn-subst honor settings for ignoring duplicate metadata
    +  Allow removing plugins during model validation
    +  Prefer namespaced metadata when duplicates are found
* Fri Oct 22 2021 Fridrich Strba <fstrba@suse.com>
- Specify maven_home manually since the diversity of alternatives
  in different distro versions makes it tedious to detect this
  automatically
* Thu May 13 2021 Fridrich Strba <fstrba@suse.com>
- Require the maven-libs we built against in order to avoid hanging
  symlinks
* Mon May 11 2020 Fridrich Strba <fstrba@suse.com>
- Do not use %%%%pretrans
* Thu Nov 21 2019 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.1.0
* Wed Mar 27 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of xmvn 3.0.0
